(library)=

# API

simtools is composed of the following modules and module groups:

```{toctree}
:glob: true
:maxdepth: 1

camera
configuration_module
corsika
data_model
dependencies
db_handler
io
job_execution
array_layout
mc_model
production_configuration
ray_tracing
reporting
runners
sim_telarray
simulators
testing
trigger
utils
visualization
```

:::{hint}
Confirm that all modules are included.
:::
